Learn R Programming

sensR (version 1.2.2)

plot.discrim: Plot function for discrim objects

Description

This function plots the latent distributions of sensory intensity corresponding to the items or products tested in the discrimination test.

Usage

## S3 method for class 'discrim':
plot(x, main = TRUE, length = 1000, ...)

Arguments

x
The discrim object whose latent distributions are to be plotted
main
include an automatically generated title on the plot? Default is TRUE
length
the length of the vectors to be plotted. Longer vectors gives more smooth curves.
...
additional arguments to plot and lines

Examples

Run this code
## Generate discrim objects to be plotted:
fm1 <- discrim(10, 15, "threeAFC")
fm2 <- discrim(10, 15, "triangle")
par(mfrow=c(2,1)) ## Split plotting window in two
## Plot the distributions of sensory intensity for the two objects
## and increase the line width
plot(fm1, lwd=2) 
plot(fm2, lwd=2)

Run the code above in your browser using DataLab