Learn R Programming

sensR (version 1.2.2)

profile.discrim: Profile likelihood methods for discrim objects.

Description

Computes the (normalized or relative) profile likelihood for the parameters of a discrimination test, plots the normalized profile likelihood and computes profile likelihood confidence intervals.

Usage

## S3 method for class 'discrim':
profile(fitted, min = 0, max = 3, numpts = 50, ...)

## S3 method for class 'profile.discrim':
plot(x, level = c(0.99, 0.95), fig = TRUE,
            method = "natural", n = 500, ...)

## S3 method for class 'discrim':
confint(object, parm, level = 0.95, ...)

Arguments

fitted
a discrim object.
x
a profile.discrim object.
object
a discrim object.
parm
currently not used.
min
the minimum delta for which to do the profiling. By default set to 0, which for numerical stability is change internally to 1e-4.
max
the maximum delta beyond the MLE for which to do the profiling.
numpts
control parameter: At how many points should the profile likelihood be evaluated?
method
the type of spline to be used in approximating the profile likelhood curve (trace)---se spline for details.
n
the number of spline interpolations to use in plotting the profile likelihood curve (trace).
level
for plot: At which levels to include horizontal lines to indicate confidence levels in plots of the normalized profile likelihoods. For confint: at which level to compute the confidence interval.
fig
logical: Should the normalized profile likelihoods be plotted?
...
For plot: additional arguments to plot. For confint: additional arguments to confint.glm in package MASS. For profile: additional arguments to

Value

  • For profile: An object of class "profile.discrim", "data.frame"---a data.frame with two columns giving the value of the parameter and the corresponding value of the profile likelihood. For plot: An object of class "nProfile.discrim", "data.frame"---the data.frame from the profile-object with an extra columns containing the normalized profile likelihood. For confint: A 2x2 matrix with columns named "lower", "upper" giving the lower and upper (1 - alpha)% confidence interval for the parameters named in the rows.

References

Brockhoff, P.B. and Christensen R.H.B. (2010). Thurstonian models for sensory discrimination tests as generalized linear models. Food Quality and Preference, 21, pp. 330-338.

Examples

Run this code
## 7 success out of 10 samples in a duo-trio experiment:
dd <- discrim(7, 10, "duotrio")
plot(profile(dd))
confint(dd)
points(confint(dd), rep(.1465, 2), pch = 3)

Run the code above in your browser using DataLab