Learn R Programming

sensR (version 1.2.2)

samediff: Computation of tau and dprime for same different test

Description

Computation of tau and dprime and their uncertainties for the same different test using maximum likelihood.

Usage

samediff(nsamesame, ndiffsame, nsamediff, ndiffdiff, VCOV = TRUE)

Arguments

nsamesame
The number of same-answers on same-samples
ndiffsame
The number of different-answers on same-samples
nsamediff
The number of same-answers on different-samples
ndiffdiff
The number of different-answers on different-samples
VCOV
Should the variance-covariance matrix of the parameters be computed. Defaults to TRUE.

Value

  • An object of class samediff with elements
  • coefnamed vector of coefficients (d-prime and tau)
  • vcovvariance-covariance matrix of the coefficients
  • senamed vector with standard error of the coefficients (standard error of d-prime)
  • dataa named vector with the data supplied to the function
  • testa string with the name of the test (same-different)
  • callthe matched call
  • convergenceconvergence indicater. 0 indicates convergence. For error codes see optim.
  • logLikValue of the log-likelhood at the MLE of the parameters.
  • caseA case indicator for internal use

Details

The function computes the maximum likelihood estimates of tau and delta.

References

Christensen, R.H.B., Brockhoff, P.B. (2009). Estimation and inference in the same-different test. Food, Quality and Preference, 20 pp. 514--520

Examples

Run this code
# data: 8 of the same samples were judged to be same
#       5 of the same samples were judged to be different
#       4 of the different samples were judged to be same
#       9 of the different samples were judged to be different

samediff(8, 5, 4, 9)

Run the code above in your browser using DataLab