Usage
ROC(object, ...)
## S3 method for class 'default':
ROC(object, se.d, scale = 1, length = 1000,
fig = TRUE, se.type = c("CI", "SE"), CI.alpha = 0.05, ...)
## S3 method for class 'discrim':
ROC(object, length = 1000, fig = TRUE,
se.type = c("CI", "SE"), CI.alpha = 0.05, ...)Arguments
object
the class of the object defines, which of the methods is
invoked. If obejct is a single element numeric vector it is taken as
a d-prime value and the default method is invoked. If the object is
of class discrim (works for AnotA
se.d
a unit length vector with the standard error of
d-prime. If supplied confidence intervals or standard errors are
plotted
scale
a unit length vector giving the ratio of scale (ie. standard
deviation) of the latent distribution for the no-class items relative to
that of the yes-class items
length
the length of the vectors to be plotted. Longer vectors
gives more smooth curves.
fig
Should a plot be produced?
se.type
The type of band for the ROC curve, "CI" for
confidence interval and "SE" for standard error.
CI.alpha
the type I level of the confidence interval of AUC
...
additional arguments to plot and lines