clls(location, scale, data, weights, start, ..., subset,
na.action, contrasts = NULL, Hess = FALSE, model = TRUE,
method = c("logistic", "probit", "cloglog", "cauchit"))response ~ predictors. The response should be a factor
(preferably an ordered factor), which will be interpreted as an
ordinal response, with levels ordered as in the factor.
~ predictors, ie. with an empty left hand side.
If left unspecified, the model assumes a constant scale and reduces
to the cumulative link model.
An offset may be useformula.c(beta, theta, sigma): see the Values section.optim, most often a
control argument.summary or
vcov on the fit."clls". This has componentsbeta), the intercepts (theta) and the scale
(sigma).tau = log sigma.response, with
the fitted probabilities on a case-by-case basis.terms structure describing the location
part.terms structure describing the scale
part.optim.optim.Hess is true, the observed Fisher information
matrix.model is true, the model.frame for
the location part.model is true, the model.frame for
the scale part.polr in
package MASS and should give compatible results, if scale is
left unspecified. Note that standard errors are appropriate for tau =
log sigma and not for sigma, because the profile
likelihood is usually more symmetric for tau than for
sigma. Therefore vcov will give the
variance-covariance matrix of the parameters with tau rather
than sigma and summary.clls will report standard errors
for log sigma. Notice also that a relevant test for
sigma is $H_0: sigma = 1$, so the relevant test for log
sigma is $H_0: log(sigma) = 0$. This is reflected in the z
value for sigma returned by summary.clls.
There are methods for the standard model-fitting functions, including
summary, vcov,
anova, and an
extractAIC method.
Christensen, R. H. B., Brockhoff, P. B. and Cleaver, G. (2008) Estimation and Inference in the A-Not A test with Sureness. Manuscript for Food Quality and Preference. Venables, W. N. and Ripley, B. D. (2002) Modern Applied Statistics with S. Fourth edition. Springer.
polr, optim, glm,
multinom.options(contrasts = c("contr.treatment", "contr.poly"))
## Extend example from polr in package MASS:
## Fit model from polr example:
data(housing, package = "MASS")
fm1 <- clls(Sat ~ Infl + Type + Cont, weights = Freq, data = housing)
fm1
summary(fm1)
## With probit link:
summary(update(fm1, method = "probit"))
## Allow scale to depend on Cont-variable
summary(fm2 <- update(fm1, scale =~ Cont))
anova(fm1, fm2)
## which seems to improve the fitRun the code above in your browser using DataLab