## S3 method for class 'discrim':
profile(fitted, min = 0, max = 3, numpts = 50, ...)
## S3 method for class 'profile.discrim':
plot(x, level = c(0.99, 0.95), fig = TRUE,
method = "natural", n = 500, ...)
## S3 method for class 'discrim':
confint(object, parm, level = 0.95, ...)discrim object.profile.discrim object.discrim object.spline for
details.plot: At which levels to include horizontal lines to indicate
confidence levels in plots of the normalized profile
likelihoods. For confint: at which level to compute the
confidence interval.plot: additional arguments to plot. For
confint: additional arguments to confint.glm in
package MASS. For profile: additional arguments to
profile:
An object of class "profile.discrim", "data.frame"---a
data.frame with two columns giving
the value of the parameter and the corresponding value of the profile
likelihood.
For plot:
An object of class "nProfile.discrim", "data.frame"---the
data.frame from the profile-object with an extra
columns containing the
normalized profile likelihood.
For confint:
A 2x2 matrix with columns named "lower", "upper" giving the
lower and upper (1 - alpha)% confidence interval for the
parameters named in the rows.## 7 success out of 10 samples in a duo-trio experiment:
dd <- discrim(7, 10, "duotrio")
plot(profile(dd))
confint(dd)
points(confint(dd), rep(.1465, 2), pch = 3)Run the code above in your browser using DataLab